#
# spec file for package gcc
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gcc
%define separate_bi32 0
%define separate_bi64 0
%ifarch ppc
%define separate_bi64 1
%endif
%ifarch x86_64 s390x ppc64
%define separate_bi32 1
%endif
# Ada currently fails to build on a few platforms, enable it only
# on those that work
# Note that AdaCore only supports %ix86, x86_64 and ia64
%ifarch %ix86 x86_64 ppc ppc64 s390 ia64
%define build_ada 1
%else
# alpha ppc64 s390x hppa arm
%define build_ada 0
%endif
Url:            http://gcc.gnu.org/
%define gcc_version 48
%define gcc_suffix 4.8
Version:        4.8
Release:        11.16
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Provides:       c_compiler
Obsoletes:      gcc-ar
Obsoletes:      gcc-mudflap
Obsoletes:      gcc-nm
Obsoletes:      gcc-ranlib
Requires:       cpp
Requires:       gcc%{gcc_version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc%{gcc_version}
Source:         cpp
Source99:       README.packaging

%description
The system GNU C Compiler.



%package -n gcc-32bit
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-32bit

%description -n gcc-32bit
The system GNU C Compiler.



%package -n gcc-64bit
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-64bit

%description -n gcc-64bit
The system GNU C Compiler.



%package -n cpp
Summary:        The system GNU Preprocessor
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       cpp%{gcc_version}

%description -n cpp
The system GNU Preprocessor.



%package -n gcc-locale
Summary:        The system GNU Compiler locale files
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-locale

%description -n gcc-locale
The system GNU Compiler locale files.



%package -n gcc-info
Summary:        The system GNU Compiler documentation
License:        GFDL-1.2
Group:          Development/Languages/C and C++
PreReq:         %{install_info_prereq}
PreReq:         gcc%{gcc_version}-info

%description -n gcc-info
The system GNU Compiler documentation.

# install / update the entries
%post -n gcc-info
%install_info --info-dir=%{_infodir} --name=cpp --description='The GNU C preprocessor.' %{_infodir}/cpp.info.gz
%install_info --info-dir=%{_infodir} --name=gcc --description='The GNU Compiler Collection.' %{_infodir}/gcc.info.gz
%install_info --info-dir=%{_infodir} --name=g++ --description='The GNU C++ compiler.' %{_infodir}/g++.info.gz
%install_info --info-dir=%{_infodir} --name=gcj --description='Ahead-of-time compiler for the Java language' %{_infodir}/gcj.info.gz
%install_info --info-dir=%{_infodir} --name=gfortran --description='The GNU Fortran compiler.' %{_infodir}/gfortran.info.gz

# if we uninstall, clean the entries
%preun -n gcc-info
if [ "$1" -eq "0" ] ; then
  %install_info --delete --info-dir=%{_infodir} --name=cpp %{_infodir}/cpp.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=gcc %{_infodir}/gcc.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=g++ %{_infodir}/g++.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=gcj %{_infodir}/gcj.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=gfortran %{_infodir}/gfortran.info.gz
fi

%package -n gcc-c++
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Provides:       c++_compiler
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-c++

%description -n gcc-c++
The system GNU C++ Compiler.


%package -n gcc-c++-32bit
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc-32bit = %{version}
Requires:       gcc-c++ = %{version}
Requires:       libstdc++%{gcc_version}-devel-32bit

%description -n gcc-c++-32bit
The system GNU C++ Compiler 32 bit support.


%package -n gcc-c++-64bit
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc-64bit = %{version}
Requires:       gcc-c++ = %{version}
Requires:       libstdc++%{gcc_version}-devel-64bit

%description -n gcc-c++-64bit
The system GNU C++ Compiler 64 bit support.



%package -n libstdc++-devel
Summary:        The system GNU C++ development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++%{gcc_version}-devel

%description -n libstdc++-devel
The system GNU C++ development files.


%package -n libstdc++-devel-32bit
Summary:        The system GNU C++ 32bit development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++%{gcc_version}-devel-32bit

%description -n libstdc++-devel-32bit
The system GNU C++ 32bit development files.


%package -n libstdc++-devel-64bit
Summary:        The system GNU C++ 64bit development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++%{gcc_version}-devel-64bit

%description -n libstdc++-devel-64bit
The system GNU C++ 64bit development files.



%package -n gcc-fortran
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-fortran

%description -n gcc-fortran
The system GNU Fortran Compiler.


%package -n gcc-fortran-32bit
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc%{gcc_version}-fortran-32bit
Requires:       gcc-fortran = %{version}

%description -n gcc-fortran-32bit
The system GNU Fortran Compiler 32 bit support.


%package -n gcc-fortran-64bit
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc%{gcc_version}-fortran-64bit
Requires:       gcc-fortran = %{version}

%description -n gcc-fortran-64bit
The system GNU Fortran Compiler 64 bit support.


%package -n gcc-java
Summary:        The system GNU Java Compiler
License:        GPL-3.0+
Group:          Development/Languages/Java
Requires:       gcc%{gcc_version}-java
Requires:       libgcj-devel = %{version}
Recommends:     gcc-gij = %{version}
Requires:       gcc = %{version}

%description -n gcc-java
The system GNU Java Compiler.



%package -n libgcj-devel
Summary:        The system GNU Java development files.
License:        GPL-2.0-with-classpath-exception
Group:          Development/Libraries/Java
Requires:       libgcj%{gcc_version}-devel

%description -n libgcj-devel
The system GNU Java development files.



%package -n gcc-gij
Summary:        The system GNU Java bytecode interpreter
License:        GPL-2.0+
Group:          Development/Languages/Java
Requires:       gcc%{gcc_version}-gij

%description -n gcc-gij
The system GNU Java bytecode interpreter.



%package -n gcc-gij-32bit
Summary:        The system GNU Java bytecode interpreter
License:        GPL-2.0+
Group:          Development/Languages/Java
Requires:       gcc%{gcc_version}-gij-32bit

%description -n gcc-gij-32bit
The system GNU Java bytecode interpreter as 32 bit application.



%package -n gcc-gij-64bit
Summary:        The system GNU Java bytecode interpreter
License:        GPL-2.0+
Group:          Development/Languages/Java
Requires:       gcc%{gcc_version}-gij-64bit

%description -n gcc-gij-64bit
The system GNU Java bytecode interpreter as 64 bit application.



%package -n gcc-objc
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-objc
%ifarch ppc64
Obsoletes:      gcc-objc-64bit
%endif

%description -n gcc-objc
The system GNU Objective C Compiler.



%package -n gcc-objc-32bit
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-objc-32bit
Requires:       gcc-objc = %{version}

%description -n gcc-objc-32bit
The system GNU Objective C Compiler 32 bit support.



%package -n gcc-objc-64bit
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-objc-64bit
Requires:       gcc-objc = %{version}

%description -n gcc-objc-64bit
The system GNU Objective C Compiler 64 bit support.



%package -n gcc-obj-c++
Summary:        The system GNU Objective C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-obj-c++
Requires:       gcc-objc = %{version}

%description -n gcc-obj-c++
The system GNU Objective C++ Compiler.


%if %{build_ada}
%package -n gcc-ada
Summary:        The system GNU Ada Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-ada

%description -n gcc-ada
The system GNU Ada Compiler.
%endif

%prep 

%build
echo "This is a dummy package to provide a dependency on the system compiler." > README

%install
mkdir -p $RPM_BUILD_ROOT/lib
mkdir -p $RPM_BUILD_ROOT%{_prefix}/bin
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
mkdir -p $RPM_BUILD_ROOT%{_infodir}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/share/doc/packages/gcc-objc/
mkdir -p $RPM_BUILD_ROOT%{_prefix}/share/doc/packages/gcc-obj-c++/
# Link all the binaries
for program in \
        gcc gcov \
        g++ \
        cpp \
	gcj gcjh gcj-dbtool jcf-dump jv-convert gc-analyze \
	gij \
	gappletviewer \
	gjar gjarsigner gjavah gkeytool gnative2ascii gorbd grmic \
	grmid grmiregistry gserialver gtnameserv \
%if %{separate_bi32}
	grmiregistry32 \
	gij32 \
%endif
%if %{separate_bi64}
	grmiregistry64 \
	gij64 \
%endif
        gfortran \
%if %{build_ada}
	gnat gnatbind gnatbl gnatchop gnatclean gnatfind gnatkr \
	gnatlink gnatls gnatmake gnatname gnatprep gnatxref gprmake \
%endif
	gcc-ar gcc-nm gcc-ranlib \
    ; do
  ln -sf $program-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/$program
done
# Link section 1 manpages
for man1 in \
        gcc gcov \
        g++ \
        cpp \
        gfortran \
	gcj gcjh gcj-dbtool jcf-dump jv-convert gc-analyze \
	gij \
	gappletviewer gjar gjarsigner gjavah \
	gkeytool gnative2ascii gorbd grmic grmid grmiregistry gserialver \
	gtnameserv \
    ; do
  ln -sf $man1-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/$man1.1.gz
done
# Link info pages
for info in cpp gcc g++ gcj gfortran ; do
  ln -sf $info-%{gcc_suffix}.info.gz $RPM_BUILD_ROOT%{_infodir}/$info.info.gz
done
# Provide the traditional /lib/cpp that only handles C
cp $RPM_SOURCE_DIR/cpp $RPM_BUILD_ROOT/lib/
chmod 755 $RPM_BUILD_ROOT/lib/cpp
# Provide extra symlinks
ln -sf g++-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/c++
ln -sf gcc-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/cc
ln -sf g++-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/c++.1.gz
ln -sf gcc-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/cc.1.gz

%files
%defattr(-,root,root)
%{_prefix}/bin/gcc
%{_prefix}/bin/cc
%{_prefix}/bin/gcov
%{_prefix}/bin/gcc-ar
%{_prefix}/bin/gcc-nm
%{_prefix}/bin/gcc-ranlib
%doc %{_mandir}/man1/gcc.1.gz
%doc %{_mandir}/man1/cc.1.gz
%doc %{_mandir}/man1/gcov.1.gz

%files -n cpp
%defattr(-,root,root)
/lib/cpp
%{_prefix}/bin/cpp
%doc %{_mandir}/man1/cpp.1.gz

%files -n gcc-c++
%defattr(-,root,root)
%{_prefix}/bin/g++
%{_prefix}/bin/c++
%doc %{_mandir}/man1/g++.1.gz
%doc %{_mandir}/man1/c++.1.gz

%files -n gcc-fortran
%defattr(-,root,root)
%{_prefix}/bin/gfortran
%doc %{_mandir}/man1/gfortran.1.gz

%files -n gcc-java
%defattr(-,root,root)
%{_prefix}/bin/gcj
%{_prefix}/bin/gcjh
%{_prefix}/bin/gcj-dbtool
%{_prefix}/bin/jcf-dump
%{_prefix}/bin/jv-convert
%{_prefix}/bin/gc-analyze
%doc %{_mandir}/man1/gcj.1.gz
%doc %{_mandir}/man1/gcjh.1.gz
%doc %{_mandir}/man1/gcj-dbtool.1.gz
%doc %{_mandir}/man1/jcf-dump.1.gz
%doc %{_mandir}/man1/jv-convert.1.gz
%doc %{_mandir}/man1/gc-analyze.1.gz

%files -n gcc-gij
%defattr(-,root,root)
%{_prefix}/bin/gij
%{_prefix}/bin/gappletviewer
%{_prefix}/bin/gjar
%{_prefix}/bin/gjarsigner
%{_prefix}/bin/gjavah
%{_prefix}/bin/gkeytool
%{_prefix}/bin/gnative2ascii
%{_prefix}/bin/gorbd
%{_prefix}/bin/grmic
%{_prefix}/bin/grmid
%{_prefix}/bin/grmiregistry
%{_prefix}/bin/gserialver
%{_prefix}/bin/gtnameserv
%doc %{_mandir}/man1/gij.1.gz
%doc %{_mandir}/man1/gappletviewer.1.gz
%doc %{_mandir}/man1/gjar.1.gz
%doc %{_mandir}/man1/gjarsigner.1.gz
%doc %{_mandir}/man1/gjavah.1.gz
%doc %{_mandir}/man1/gkeytool.1.gz
%doc %{_mandir}/man1/gnative2ascii.1.gz
%doc %{_mandir}/man1/gorbd.1.gz
%doc %{_mandir}/man1/grmic.1.gz
%doc %{_mandir}/man1/grmid.1.gz
%doc %{_mandir}/man1/grmiregistry.1.gz
%doc %{_mandir}/man1/gserialver.1.gz
%doc %{_mandir}/man1/gtnameserv.1.gz

%files -n gcc-objc
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-obj-c++
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-locale
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-info
%defattr(-,root,root)
%{_infodir}/cpp.info.gz
%{_infodir}/gcc.info.gz
%{_infodir}/g++.info.gz
%{_infodir}/gcj.info.gz
%{_infodir}/gfortran.info.gz

%if %{build_ada}
%files -n gcc-ada
%defattr(-,root,root)
%{_prefix}/bin/gnat
%{_prefix}/bin/gnatbind
%{_prefix}/bin/gnatbl
%{_prefix}/bin/gnatchop
%{_prefix}/bin/gnatclean
%{_prefix}/bin/gnatfind
%{_prefix}/bin/gnatkr
%{_prefix}/bin/gnatlink
%{_prefix}/bin/gnatls
%{_prefix}/bin/gnatmake
%{_prefix}/bin/gnatname
%{_prefix}/bin/gnatprep
%{_prefix}/bin/gnatxref
%{_prefix}/bin/gprmake
%endif

%files -n libstdc++-devel
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n libgcj-devel
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%if %{separate_bi32}

%files -n gcc-32bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-c++-32bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n libstdc++-devel-32bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-fortran-32bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-objc-32bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-gij-32bit
%defattr(-,root,root)
%{_prefix}/bin/gij32
%{_prefix}/bin/grmiregistry32

%endif
%if %{separate_bi64}

%files -n gcc-64bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-c++-64bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n libstdc++-devel-64bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-fortran-64bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-objc-64bit
%defattr(-,root,root)
# empty - only for the dependency
%doc README

%files -n gcc-gij-64bit
%defattr(-,root,root)
%{_prefix}/bin/gij64
%{_prefix}/bin/grmiregistry64

%endif

%changelog
* Mon Aug  4 2014 rguenther@suse.com
- Add libstdc++-devel-32bit and libstdc++-devel-64bit packages.
  [bnc#890226]
* Tue Feb  4 2014 rguenther@suse.com
- Remove gcc-z9 wrapper which is obsolete.
* Mon Dec  2 2013 rguenther@suse.com
- Move gcc-ar, gcc-nm and gcc-ranlib to the gcc package instead
  of packaging them separately.
* Wed Jun 19 2013 rguenther@suse.com
- Package gcc-ar, gcc-nm and gcc-ranlib wrapping ar, nm and ranlib
  in a plugin-aware fashion.
* Mon May 27 2013 rguenther@suse.com
- Switch gcc to default 4.8.
* Mon Jan  7 2013 rguenther@suse.com
- Re-enable Ada for ppc64.
* Thu Dec 13 2012 rguenther@suse.com
- Add BuildRequires to gcc$version, required for cc1 path detection.
* Wed Nov 28 2012 rguenther@suse.com
- Rework gcc-info.
  * Install symlinks to the versioned info files and adjust
    install_info calls.  [bnc#756182]
  * Provide uninstall hook that removes the alias entries.
* Thu Oct  4 2012 dmueller@suse.com
- remove gcc-ada subpackage for those architectures that
  don't have a gccXX-ada package
* Wed Apr 18 2012 rguenther@suse.com
- Switch gcc to default 4.7.
* Fri Jan 27 2012 rguenther@suse.com
- Change licenses to follow SPDX convention.
* Mon Sep 26 2011 dmueller@suse.de
- use the target gcc binary for finding the right cc1 path
* Wed May 11 2011 rguenther@novell.com
- Switch gcc to default 4.6.
* Thu Feb 10 2011 rguenther@novell.com
- Fix licenses to match those of the system compiler.  [bnc#670658]
* Tue Jan 25 2011 rguenther@novell.com
- Fix string quoting.  [bnc#666416]
* Wed Jan 12 2011 rguenther@novell.com
- Uglify spec file formatting.
* Fri Dec 10 2010 rguenther@novell.com
- Add info directory aliases for unversioned variants of the
  GCC user manuals.  [bnc#635355]
* Mon Nov 29 2010 rguenther@novell.com
- Drop libffi packages.
* Fri Feb 26 2010 rguenther@novell.com
- Fix gcc-c++-32bit and gcc-c++-64bit again.
* Thu Feb 25 2010 rguenther@suse.de
- Drop c++_compiler provides from gcc-c++-32bit and gcc-c++-64bit.
* Thu Feb 25 2010 rguenther@suse.de
- Re-add gcc-c++-32bit and gcc-c++-64bit packages.
* Tue Feb 16 2010 coolo@novell.com
- Switch gcc to default 4.5.
* Mon Apr 27 2009 rguenther@suse.de
- Switch gcc default to 4.4.
* Mon Feb 16 2009 rguenther@suse.de
- Enable links for classpath binaries and manpages again.
* Fri Jan  9 2009 rguenther@suse.de
- On ppc64 obsolete gcc-objc-64bit by gcc-objc.
* Thu Dec  4 2008 matz@suse.de
- Add new gcc-z9 package on s390 and s390x to change the
  default -march and -mtune settings.
* Wed May  7 2008 rguenther@suse.de
- Make dependencies between the gcc subpackages versioned. [bnc#385305]
* Fri Nov 23 2007 rguenther@suse.de
- Make gcc-gij dependency of gcc-java a recommendation, all java
  tools are back to the gcc-java package.  Require libgcj-devel
  from gcc-java.
- Revert /lib/cpp changes.
* Fri Nov 16 2007 rguenther@suse.de
- For now disable symlinking of binaries and manpages that
  conflict with the classpath package.
* Tue Nov 13 2007 rguenther@suse.de
- Make /lib/cpp traditional and avoid GCC and target specific
  defines.
* Tue Oct 30 2007 rguenther@suse.de
- Add gcc-gij dependency to gcc-java as it contains many of the
  tools formerly packaged in the gcc-java package.
* Mon Sep 24 2007 rguenther@suse.de
- Switch gcc default to 4.3.
* Fri Jul 27 2007 rguenther@suse.de
- Fix typo.
* Tue Jul 24 2007 rguenther@suse.de
- Add 32bit and 64bit variants of gcc-gij.  [#293423]
* Fri Jul  6 2007 rguenther@suse.de
- Mark ppc64 as separate bi-32.
* Thu Jun 14 2007 ro@suse.de
- Do not mark README.packaging as NoSource. (again)
* Fri Jun  8 2007 rguenther@suse.de
- Switch gcc default to 4.2.  [#275939]
* Tue Apr 24 2007 rguenther@suse.de
- Do not link to grmic and grmiregistry, they conflict with
  the classpath package versions.
* Tue Jan 16 2007 rguenther@suse.de
- Do not mark README.packaging as NoSource.
* Thu Nov  9 2006 rguenther@suse.de
- Remove gcc-c++-32bit and gcc-c++-64bit packages.
* Tue Oct 31 2006 dmueller@suse.de
- don't build as root
* Mon Oct 30 2006 rguenther@suse.de
- Make gcc architecture dependent again.  [#215971]
* Thu Oct 26 2006 rguenther@suse.de
- Add dependencies to the gcc and non-32/64bit packages.  [#215217]
* Tue Sep 19 2006 rguenther@suse.de
- New gcc-gij package.
* Fri Aug 25 2006 rguenther@suse.de
- Add 32bit and 64bit support packages to gcc, gcc-c++, gcc-fortran,
  gcc-objc and libffi-devel.
* Thu Aug 24 2006 rguenther@suse.de
- Make gcc require cpp to pull in /lib/cpp.
* Fri Aug 18 2006 rguenther@suse.de
- gcc obsoletes gcc-mudflap which is no longer.
* Mon Aug  7 2006 rguenther@suse.de
- Provide gcc-mudflap, gcc-info and gcc-locale packages [#197515].
* Fri Jul 14 2006 rguenther@suse.de
- New package.
